Struct phlow::PhlowObject
source · pub struct PhlowObject(/* private fields */);Implementations
sourceimpl PhlowObject
impl PhlowObject
pub fn object<T: Any>( object: T, phlow_extensions_fn: impl Fn(&T) -> Vec<PhlowExtension> + 'static ) -> Self
pub fn object_with_generics<T: 'static>( object: T, phlow_extensions_fn: impl Fn(&T) -> Vec<PhlowExtension> + 'static, generic_types: Vec<PhlowType> ) -> Self
pub fn reference<T: 'static>( object: &T, parent: &PhlowObject, phlow_extensions_fn: impl Fn(&T) -> Vec<PhlowExtension> + 'static ) -> Self
pub fn construct_reference<T: 'static>( reference: &T, phlow_type: PhlowType, parent: Option<PhlowObject> ) -> Self
pub fn new( value: AnyValue, phlow_type: PhlowType, generic_types: Vec<PhlowType>, parent: Option<PhlowObject> ) -> Self
pub fn phlow_type(&self) -> &PhlowType
pub fn generic_phlow_type(&self, index: usize) -> Option<PhlowType>
pub fn generic_phlow_types(&self) -> &[PhlowType]
pub fn to_string(&self) -> String
sourcepub fn has_value(&self) -> bool
pub fn has_value(&self) -> bool
Return true if phlow object contains a value - object or reference. Note, that even though has_value() may return true, it does not mean that the value can actually be taken, because it does not check the runtime type.
sourcepub fn take_value<T: Any>(&self) -> Option<T>
pub fn take_value<T: Any>(&self) -> Option<T>
Take the ownership of the value leaving AnyValue::None in its place. The value can only be taken if phlow object owned it
sourcepub fn replace_value<T: Any>(&self, object: T) -> Option<T>
pub fn replace_value<T: Any>(&self, object: T) -> Option<T>
Replace an existing value with the given object and returns the previous object if any.
sourcepub fn clone_value<T: Any + Clone>(&self) -> Option<T>
pub fn clone_value<T: Any + Clone>(&self) -> Option<T>
Attempts to clone the value
pub fn with_value<R>(&self, op: impl FnOnce(&AnyValue) -> R) -> R
pub fn value(&self) -> RwLockReadGuard<'_, RawRwLock, AnyValue>
pub fn value_mut<T: Any>( &self ) -> Option<MappedRwLockWriteGuard<'_, RawRwLock, T>>
pub fn value_ref<T: Any>( &self ) -> Option<MappedRwLockReadGuard<'_, RawRwLock, T>>
pub fn value_ptr(&self) -> *const c_void
pub fn value_type_name(&self) -> &str
pub fn parent(&self) -> Option<&PhlowObject>
pub fn phlow_view_methods(&self) -> Vec<PhlowViewMethod>
pub fn phlow_view_named( &self, name: impl AsRef<str> ) -> Option<Box<dyn PhlowView>>
pub fn phlow_views(&self) -> Vec<Box<dyn PhlowView>>