RowBuilderWithoutSend

Struct RowBuilderWithoutSend 

pub struct RowBuilderWithoutSend<T: ?Sized, Item: ?Sized> { /* private fields */ }

Implementations

Source

impl<T: ?Sized, Item: ?Sized> RowBuilderWithoutSend<T, Item>

pub fn text( self, text: impl Fn(&Item) -> String + Send + Sync + 'static, ) -> Self

pub fn text_str( self, text: impl Fn(&Item) -> &str + Send + Sync + 'static, ) -> Self

pub fn send<SentItem: Send + Sync>( self, send: impl Fn(&Item) -> SentItem + Send + Sync + 'static, ) -> RowBuilderWithSend<T, Item, SentItem>

Source

impl<T: ?Sized, Item: Copy + Send + Sync> RowBuilderWithoutSend<T, Item>

pub fn send_copy(self) -> RowBuilderWithSend<T, Item, Item>

Source

impl<T: ?Sized, Item: Clone + Send + Sync> RowBuilderWithoutSend<T, Item>

pub fn send_clone(self) -> RowBuilderWithSend<T, Item, Item>

Sends a cloned item.

Prefer this over send(|item| item.clone()) when the item itself should be sent.

Source

impl<T: ?Sized, Item: Send + Sync> RowBuilderWithoutSend<T, Option<Item>>

pub fn try_send<SentItem: Send + Sync>( self, send: impl Fn(&Item) -> SentItem + Send + Sync + 'static, ) -> RowBuilderWithSend<T, Option<Item>, SentItem>

Sends a derived item only when the row item is Some(...).

This API is intentionally only available for Option<T> row items. Use item(...) or item_ref(...) to keep the row item as Option<T>, then text(...) to render it.

Source

impl<T: ?Sized, Item: Copy + Send + Sync> RowBuilderWithoutSend<T, Option<Item>>

pub fn try_send_copy(self) -> RowBuilderWithSend<T, Option<Item>, Item>

Sends the inner copied item only when the row item is Some(...).

Source

impl<T: ?Sized, Item: Clone + Send + Sync> RowBuilderWithoutSend<T, Option<Item>>

pub fn try_send_clone(self) -> RowBuilderWithSend<T, Option<Item>, Item>

Sends the inner cloned item only when the row item is Some(...).

Prefer this over try_send(|item| item.clone()) when the row item is Option<T> and the sent object should be the contained domain item, not its string representation.